pyesmda.ESMDA
=============

.. currentmodule:: pyesmda

.. autoclass:: ESMDA
   :members:                                    <-- add at least this line
   :private-members:
   :show-inheritance:                           <-- plus I want to show inheritance...
   :inherited-members:                          <-- ...and inherited members too

   
   .. automethod:: __init__

   
   .. rubric:: Public methods summary

   .. autosummary::
   
      ~ESMDA.__init__
      ~ESMDA.solve
   
   
   

   .. rubric:: Methods definition